from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import configuration_identity_pb2 as _configuration_identity_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeIdentityConfigInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeIdentityConfigOutput(_message.Message):
    __slots__ = ("config",)
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: _configuration_identity_pb2.IdentityConfig
    def __init__(self, config: _Optional[_Union[_configuration_identity_pb2.IdentityConfig, _Mapping]] = ...) -> None: ...

class ConfigureIdentityConfigInput(_message.Message):
    __slots__ = ("config",)
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: _configuration_identity_pb2.IdentityConfig
    def __init__(self, config: _Optional[_Union[_configuration_identity_pb2.IdentityConfig, _Mapping]] = ...) -> None: ...

class ConfigureIdentityConfigOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Claims(_message.Message):
    __slots__ = ("id", "issuer", "subject", "session_id", "email", "email_verified", "email_restricted", "name", "nickname", "picture", "locale", "timezone", "birthday", "minor", "country", "preferred_runtime", "restrictions")
    ID_FIELD_NUMBER: _ClassVar[int]
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EMAIL_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    EMAIL_RESTRICTED_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NICKNAME_FIELD_NUMBER: _ClassVar[int]
    PICTURE_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    MINOR_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_RUNTIME_FIELD_NUMBER: _ClassVar[int]
    RESTRICTIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    issuer: str
    subject: str
    session_id: str
    email: str
    email_verified: bool
    email_restricted: bool
    name: str
    nickname: str
    picture: str
    locale: str
    timezone: str
    birthday: str
    minor: bool
    country: str
    preferred_runtime: str
    restrictions: str
    def __init__(self, id: _Optional[str] = ..., issuer: _Optional[str] = ..., subject: _Optional[str] = ..., session_id: _Optional[str] = ..., email: _Optional[str] = ..., email_verified: bool = ..., email_restricted: bool = ..., name: _Optional[str] = ..., nickname: _Optional[str] = ..., picture: _Optional[str] = ..., locale: _Optional[str] = ..., timezone: _Optional[str] = ..., birthday: _Optional[str] = ..., minor: bool = ..., country: _Optional[str] = ..., preferred_runtime: _Optional[str] = ..., restrictions: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ResourceUsage(_message.Message):
    __slots__ = ("user_cpu_time", "system_cpu_time", "max_resident_set_size", "page_reclaims", "page_faults", "block_input_operations", "block_output_operations", "voluntary_context_switches", "involuntary_context_switches")
    USER_CPU_TIME_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_CPU_TIME_FIELD_NUMBER: _ClassVar[int]
    MAX_RESIDENT_SET_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_RECLAIMS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FAULTS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_INPUT_OPERATIONS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_OUTPUT_OPERATIONS_FIELD_NUMBER: _ClassVar[int]
    VOLUNTARY_CONTEXT_SWITCHES_FIELD_NUMBER: _ClassVar[int]
    INVOLUNTARY_CONTEXT_SWITCHES_FIELD_NUMBER: _ClassVar[int]
    user_cpu_time: int
    system_cpu_time: int
    max_resident_set_size: int
    page_reclaims: int
    page_faults: int
    block_input_operations: int
    block_output_operations: int
    voluntary_context_switches: int
    involuntary_context_switches: int
    def __init__(self, user_cpu_time: _Optional[int] = ..., system_cpu_time: _Optional[int] = ..., max_resident_set_size: _Optional[int] = ..., page_reclaims: _Optional[int] = ..., page_faults: _Optional[int] = ..., block_input_operations: _Optional[int] = ..., block_output_operations: _Optional[int] = ..., voluntary_context_switches: _Optional[int] = ..., involuntary_context_switches: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/email_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/community/email_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import email_type_pb2 as eolymp_dot_community_dot_email__type__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/community/email_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a!eolymp/community/email_type.proto\x1a\x1d\x65olymp/community/member.proto\x1a\x18\x65olymp/ecm/content.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xaf\x02\n\x0eSendEmailInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x14 \x01(\x08\x12\x0e\n\x06\x62\x63\x63_me\x18\x15 \x01(\x08\x12)\n\x04type\x18\n \x01(\x0e\x32\x1b.eolymp.community.EmailType\x12\x0e\n\x06locale\x18\x0b \x01(\t\x12\x0f\n\x07subject\x18\x0c \x01(\t\x12$\n\x07\x63ontent\x18\r \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x44\n\nparameters\x18\x0e \x03(\x0b\x32\x30.eolymp.community.SendEmailInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x0fSendEmailOutput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65scribeEmailUsageInput\"H\n\x18\x44\x65scribeEmailUsageOutput\x12\x14\n\x0c\x64\x61ily_emails\x18\x02 \x01(\r\x12\x16\n\x0emonthly_emails\x18\x03 \x01(\r2\xe4\x02\n\x0c\x45mailService\x12\xa2\x01\n\tSendEmail\x12 .eolymp.community.SendEmailInput\x1a!.eolymp.community.SendEmailOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/members/{member_id}/notify\x12\xae\x01\n\x12\x44\x65scribeEmailUsage\x12).eolymp.community.DescribeEmailUsageInput\x1a*.eolymp.community.DescribeEmailUsageOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x0f\x12\r/usage/emailsB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.email_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_SENDEMAILINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_SENDEMAILINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_EMAILSERVICE'].methods_by_name['SendEmail']._loaded_options = None
  _globals['_EMAILSERVICE'].methods_by_name['SendEmail']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\035\"\033/members/{member_id}/notify'
  _globals['_EMAILSERVICE'].methods_by_name['DescribeEmailUsage']._loaded_options = None
  _globals['_EMAILSERVICE'].methods_by_name['DescribeEmailUsage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\017\022\r/usage/emails'
  _globals['_SENDEMAILINPUT']._serialized_start=352
  _globals['_SENDEMAILINPUT']._serialized_end=655
  _globals['_SENDEMAILINPUT_PARAMETERSENTRY']._serialized_start=606
  _globals['_SENDEMAILINPUT_PARAMETERSENTRY']._serialized_end=655
  _globals['_SENDEMAILOUTPUT']._serialized_start=657
  _globals['_SENDEMAILOUTPUT']._serialized_end=694
  _globals['_DESCRIBEEMAILUSAGEINPUT']._serialized_start=696
  _globals['_DESCRIBEEMAILUSAGEINPUT']._serialized_end=721
  _globals['_DESCRIBEEMAILUSAGEOUTPUT']._serialized_start=723
  _globals['_DESCRIBEEMAILUSAGEOUTPUT']._serialized_end=795
  _globals['_EMAILSERVICE']._serialized_start=798
  _globals['_EMAILSERVICE']._serialized_end=1154
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import email_type_pb2 as _email_type_pb2
from eolymp.community import member_pb2 as _member_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SendEmailInput(_message.Message):
    __slots__ = ("member_id", "dry_run", "bcc_me", "type", "locale", "subject", "content", "parameters")
    class ParametersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    DRY_RUN_FIELD_NUMBER: _ClassVar[int]
    BCC_ME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    dry_run: bool
    bcc_me: bool
    type: _email_type_pb2.EmailType
    locale: str
    subject: str
    content: _content_pb2.Content
    parameters: _containers.ScalarMap[str, str]
    def __init__(self, member_id: _Optional[str] = ..., dry_run: bool = ..., bcc_me: bool = ..., type: _Optional[_Union[_email_type_pb2.EmailType, str]] = ..., locale: _Optional[str] = ..., subject: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., parameters: _Optional[_Mapping[str, str]] = ...) -> None: ...

class SendEmailOutput(_message.Message):
    __slots__ = ("message_id",)
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    message_id: str
    def __init__(self, message_id: _Optional[str] = ...) -> None: ...

class DescribeEmailUsageInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeEmailUsageOutput(_message.Message):
    __slots__ = ("daily_emails", "monthly_emails")
    DAILY_EMAILS_FIELD_NUMBER: _ClassVar[int]
    MONTHLY_EMAILS_FIELD_NUMBER: _ClassVar[int]
    daily_emails: int
    monthly_emails: int
    def __init__(self, daily_emails: _Optional[int] = ..., monthly_emails: _Optional[int] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.playground import run_pb2 as _run_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateRunInput(_message.Message):
    __slots__ = ("runtime", "source", "input_data", "input_ref")
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    INPUT_DATA_FIELD_NUMBER: _ClassVar[int]
    INPUT_REF_FIELD_NUMBER: _ClassVar[int]
    runtime: str
    source: str
    input_data: bytes
    input_ref: str
    def __init__(self, runtime: _Optional[str] = ..., source: _Optional[str] = ..., input_data: _Optional[bytes] = ..., input_ref: _Optional[str] = ...) -> None: ...

class CreateRunOutput(_message.Message):
    __slots__ = ("run_id",)
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    def __init__(self, run_id: _Optional[str] = ...) -> None: ...

class DescribeRunInput(_message.Message):
    __slots__ = ("run_id",)
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    def __init__(self, run_id: _Optional[str] = ...) -> None: ...

class DescribeRunOutput(_message.Message):
    __slots__ = ("run",)
    RUN_FIELD_NUMBER: _ClassVar[int]
    run: _run_pb2.Run
    def __init__(self, run: _Optional[_Union[_run_pb2.Run, _Mapping]] = ...) -> None: ...

class WatchRunInput(_message.Message):
    __slots__ = ("run_id",)
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    def __init__(self, run_id: _Optional[str] = ...) -> None: ...

class WatchRunOutput(_message.Message):
    __slots__ = ("run",)
    RUN_FIELD_NUMBER: _ClassVar[int]
    run: _run_pb2.Run
    def __init__(self, run: _Optional[_Union[_run_pb2.Run, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.reward import achievement_pb2 as _achievement_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateAchievementInput(_message.Message):
    __slots__ = ("achievement",)
    ACHIEVEMENT_FIELD_NUMBER: _ClassVar[int]
    achievement: _achievement_pb2.Achievement
    def __init__(self, achievement: _Optional[_Union[_achievement_pb2.Achievement, _Mapping]] = ...) -> None: ...

class CreateAchievementOutput(_message.Message):
    __slots__ = ("achievement_id",)
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    def __init__(self, achievement_id: _Optional[str] = ...) -> None: ...

class UpdateAchievementInput(_message.Message):
    __slots__ = ("achievement_id", "achievement")
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    ACHIEVEMENT_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    achievement: _achievement_pb2.Achievement
    def __init__(self, achievement_id: _Optional[str] = ..., achievement: _Optional[_Union[_achievement_pb2.Achievement, _Mapping]] = ...) -> None: ...

class UpdateAchievementOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteAchievementInput(_message.Message):
    __slots__ = ("achievement_id",)
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    def __init__(self, achievement_id: _Optional[str] = ...) -> None: ...

class DeleteAchievementOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeAchievementInput(_message.Message):
    __slots__ = ("achievement_id", "extra")
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    extra: _containers.RepeatedScalarFieldContainer[_achievement_pb2.Achievement.Extra]
    def __init__(self, achievement_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_achievement_pb2.Achievement.Extra, str]]] = ...) -> None: ...

class DescribeAchievementOutput(_message.Message):
    __slots__ = ("achievement",)
    ACHIEVEMENT_FIELD_NUMBER: _ClassVar[int]
    achievement: _achievement_pb2.Achievement
    def __init__(self, achievement: _Optional[_Union[_achievement_pb2.Achievement, _Mapping]] = ...) -> None: ...

class ListAchievementsInput(_message.Message):
    __slots__ = ("after", "size", "offset", "filters", "extra")
    class Filter(_message.Message):
        __slots__ = ("query", "id")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        query: str
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    AFTER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    after: str
    size: int
    offset: int
    filters: ListAchievementsInput.Filter
    extra: _containers.RepeatedScalarFieldContainer[_achievement_pb2.Achievement.Extra]
    def __init__(self, after: _Optional[str] = ..., size: _Optional[int] = ..., offset: _Optional[int] = ..., filters: _Optional[_Union[ListAchievementsInput.Filter, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_achievement_pb2.Achievement.Extra, str]]] = ...) -> None: ...

class ListAchievementsOutput(_message.Message):
    __slots__ = ("total", "next_page_cursor", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_CURSOR_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    next_page_cursor: str
    items: _containers.RepeatedCompositeFieldContainer[_achievement_pb2.Achievement]
    def __init__(self, total: _Optional[int] = ..., next_page_cursor: _Optional[str] = ..., items: _Optional[_Iterable[_Union[_achievement_pb2.Achievement, _Mapping]]] = ...) -> None: ...

class DescribeAchievementTranslationInput(_message.Message):
    __slots__ = ("achievement_id", "translation_id", "extra")
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    translation_id: str
    extra: _containers.RepeatedScalarFieldContainer[_achievement_pb2.Achievement.Extra]
    def __init__(self, achievement_id: _Optional[str] = ..., translation_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_achievement_pb2.Achievement.Extra, str]]] = ...) -> None: ...

class DescribeAchievementTranslationOutput(_message.Message):
    __slots__ = ("translation",)
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    translation: _achievement_pb2.Achievement.Translation
    def __init__(self, translation: _Optional[_Union[_achievement_pb2.Achievement.Translation, _Mapping]] = ...) -> None: ...

class ListAchievementTranslationsInput(_message.Message):
    __slots__ = ("achievement_id", "offset", "size", "filters", "extra")
    class Filter(_message.Message):
        __slots__ = ("query", "id", "locale")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        query: str
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    offset: int
    size: int
    filters: ListAchievementTranslationsInput.Filter
    extra: _containers.RepeatedScalarFieldContainer[_achievement_pb2.Achievement.Extra]
    def __init__(self, achievement_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListAchievementTranslationsInput.Filter, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_achievement_pb2.Achievement.Extra, str]]] = ...) -> None: ...

class ListAchievementTranslationsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_achievement_pb2.Achievement.Translation]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_achievement_pb2.Achievement.Translation, _Mapping]]] = ...) -> None: ...

class CreateAchievementTranslationInput(_message.Message):
    __slots__ = ("achievement_id", "translation")
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    translation: _achievement_pb2.Achievement.Translation
    def __init__(self, achievement_id: _Optional[str] = ..., translation: _Optional[_Union[_achievement_pb2.Achievement.Translation, _Mapping]] = ...) -> None: ...

class CreateAchievementTranslationOutput(_message.Message):
    __slots__ = ("translation_id",)
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    translation_id: str
    def __init__(self, translation_id: _Optional[str] = ...) -> None: ...

class UpdateAchievementTranslationInput(_message.Message):
    __slots__ = ("patch", "achievement_id", "translation_id", "translation")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateAchievementTranslationInput.Patch]
        NAME: _ClassVar[UpdateAchievementTranslationInput.Patch]
        SUMMARY: _ClassVar[UpdateAchievementTranslationInput.Patch]
        LOCALE: _ClassVar[UpdateAchievementTranslationInput.Patch]
    ALL: UpdateAchievementTranslationInput.Patch
    NAME: UpdateAchievementTranslationInput.Patch
    SUMMARY: UpdateAchievementTranslationInput.Patch
    LOCALE: UpdateAchievementTranslationInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateAchievementTranslationInput.Patch]
    achievement_id: str
    translation_id: str
    translation: _achievement_pb2.Achievement.Translation
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateAchievementTranslationInput.Patch, str]]] = ..., achievement_id: _Optional[str] = ..., translation_id: _Optional[str] = ..., translation: _Optional[_Union[_achievement_pb2.Achievement.Translation, _Mapping]] = ...) -> None: ...

class UpdateAchievementTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteAchievementTranslationInput(_message.Message):
    __slots__ = ("achievement_id", "translation_id")
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    translation_id: str
    def __init__(self, achievement_id: _Optional[str] = ..., translation_id: _Optional[str] = ...) -> None: ...

class DeleteAchievementTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Direction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ASC: _ClassVar[Direction]
    DESC: _ClassVar[Direction]
ASC: Direction
DESC: Direction



from eolymp.printer import printer_pb2 as _printer_pb2
from eolymp.printer import printer_job_pb2 as _printer_job_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PrinterConnectorClientMessage(_message.Message):
    __slots__ = ("status", "report")
    class Report(_message.Message):
        __slots__ = ("id", "status")
        ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        id: str
        status: _printer_job_pb2.Job.Status
        def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[_printer_job_pb2.Job.Status, str]] = ...) -> None: ...
    class Status(_message.Message):
        __slots__ = ("status",)
        STATUS_FIELD_NUMBER: _ClassVar[int]
        status: _printer_pb2.Printer.Status
        def __init__(self, status: _Optional[_Union[_printer_pb2.Printer.Status, str]] = ...) -> None: ...
    STATUS_FIELD_NUMBER: _ClassVar[int]
    REPORT_FIELD_NUMBER: _ClassVar[int]
    status: PrinterConnectorClientMessage.Status
    report: PrinterConnectorClientMessage.Report
    def __init__(self, status: _Optional[_Union[PrinterConnectorClientMessage.Status, _Mapping]] = ..., report: _Optional[_Union[PrinterConnectorClientMessage.Report, _Mapping]] = ...) -> None: ...

class PrinterConnectorServerMessage(_message.Message):
    __slots__ = ("hello", "print")
    class Hello(_message.Message):
        __slots__ = ("comment", "printer")
        COMMENT_FIELD_NUMBER: _ClassVar[int]
        PRINTER_FIELD_NUMBER: _ClassVar[int]
        comment: str
        printer: _printer_pb2.Printer
        def __init__(self, comment: _Optional[str] = ..., printer: _Optional[_Union[_printer_pb2.Printer, _Mapping]] = ...) -> None: ...
    class Print(_message.Message):
        __slots__ = ("job",)
        JOB_FIELD_NUMBER: _ClassVar[int]
        job: _printer_job_pb2.Job
        def __init__(self, job: _Optional[_Union[_printer_job_pb2.Job, _Mapping]] = ...) -> None: ...
    HELLO_FIELD_NUMBER: _ClassVar[int]
    PRINT_FIELD_NUMBER: _ClassVar[int]
    hello: PrinterConnectorServerMessage.Hello
    print: PrinterConnectorServerMessage.Print
    def __init__(self, hello: _Optional[_Union[PrinterConnectorServerMessage.Hello, _Mapping]] = ..., print: _Optional[_Union[PrinterConnectorServerMessage.Print, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/testing_test.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/testing_test.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/atlas/testing_test.proto\x12\x0c\x65olymp.atlas\"\xe9\x04\n\x04Test\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x14 \x01(\t\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12)\n\x06status\x18< \x01(\x0e\x32\x19.eolymp.atlas.Test.Status\x12\x16\n\x0estatus_message\x18= \x01(\t\x12\x0f\n\x07\x65xample\x18\x04 \x01(\x08\x12\x10\n\x08inactive\x18\x07 \x01(\x08\x12\x0e\n\x06secret\x18\x06 \x01(\x08\x12\r\n\x05score\x18\x05 \x01(\x02\x12\x19\n\x11\x65xample_input_url\x18( \x01(\t\x12\x1a\n\x12\x65xample_answer_url\x18) \x01(\t\x12\x1b\n\x13generated_input_url\x18\x32 \x01(\t\x12\x1c\n\x14generated_answer_url\x18\x33 \x01(\t\x12\x13\n\tinput_url\x18\x0b \x01(\tH\x00\x12\x37\n\x0finput_generator\x18\x0c \x01(\x0b\x32\x1c.eolymp.atlas.Test.GeneratorH\x00\x12\x14\n\nanswer_url\x18\x15 \x01(\tH\x01\x12\x38\n\x10\x61nswer_generator\x18\x16 \x01(\x0b\x32\x1c.eolymp.atlas.Test.GeneratorH\x01\x1a\x33\n\tGenerator\x12\x13\n\x0bscript_name\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x03(\t\"A\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0b\n\x07INVALID\x10\x03\x42\x07\n\x05inputB\x08\n\x06\x61nswerB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_test_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_TEST']._serialized_start=50
  _globals['_TEST']._serialized_end=667
  _globals['_TEST_GENERATOR']._serialized_start=530
  _globals['_TEST_GENERATOR']._serialized_end=581
  _globals['_TEST_STATUS']._serialized_start=583
  _globals['_TEST_STATUS']._serialized_end=648
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class PrinterServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreatePrinter(self, request, **kwargs):
        path = "/printers"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.CreatePrinterOutput"),
            **kwargs,
        )

    def UpdatePrinter(self, request, **kwargs):
        path = "/printers/"+urllib.parse.quote(request.printer_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.printer_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.UpdatePrinterOutput"),
            **kwargs,
        )

    def DeletePrinter(self, request, **kwargs):
        path = "/printers/"+urllib.parse.quote(request.printer_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.printer_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.DeletePrinterOutput"),
            **kwargs,
        )

    def DescribePrinter(self, request, **kwargs):
        path = "/printers/"+urllib.parse.quote(request.printer_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.printer_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.DescribePrinterOutput"),
            **kwargs,
        )

    def ListPrinters(self, request, **kwargs):
        path = "/printers"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.ListPrintersOutput"),
            **kwargs,
        )

    def CreatePrinterJob(self, request, **kwargs):
        path = "/printers/"+urllib.parse.quote(request.printer_id)+"/jobs"

        # Cleanup URL parameters to avoid any ambiguity
        request.printer_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.CreatePrinterJobOutput"),
            **kwargs,
        )

    def DescribePrinterJob(self, request, **kwargs):
        path = "/printers/"+urllib.parse.quote(request.printer_id)+"/jobs/"+urllib.parse.quote(request.job_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.printer_id = ""
        request.job_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.DescribePrinterJobOutput"),
            **kwargs,
        )

    def ListPrinterJobs(self, request, **kwargs):
        path = "/printers/"+urllib.parse.quote(request.printer_id)+"/jobs"

        # Cleanup URL parameters to avoid any ambiguity
        request.printer_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.ListPrinterJobsOutput"),
            **kwargs,
        )

    def UpdatePrinterJob(self, request, **kwargs):
        path = "/printers/"+urllib.parse.quote(request.printer_id)+"/jobs/"+urllib.parse.quote(request.job_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.printer_id = ""
        request.job_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.UpdatePrinterJobOutput"),
            **kwargs,
        )

    def DeletePrinterJob(self, request, **kwargs):
        path = "/printers/"+urllib.parse.quote(request.printer_id)+"/jobs/"+urllib.parse.quote(request.job_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.printer_id = ""
        request.job_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.printer.DeletePrinterJobOutput"),
            **kwargs,
        )




from eolymp.judge import participant_pb2 as _participant_pb2
from eolymp.judge import score_pb2 as _score_pb2
from eolymp.judge import submission_pb2 as _submission_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubmissionCompletedEvent(_message.Message):
    __slots__ = ("contest_id", "submission")
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    submission: _submission_pb2.Submission
    def __init__(self, contest_id: _Optional[str] = ..., submission: _Optional[_Union[_submission_pb2.Submission, _Mapping]] = ...) -> None: ...

class RebuildScoreEvent(_message.Message):
    __slots__ = ("contest_id", "activity_id")
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVITY_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    activity_id: str
    def __init__(self, contest_id: _Optional[str] = ..., activity_id: _Optional[str] = ...) -> None: ...

class ScoreChangedEvent(_message.Message):
    __slots__ = ("contest_id", "participant_id", "unofficial", "score")
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    participant_id: str
    unofficial: bool
    score: _score_pb2.Score
    def __init__(self, contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., unofficial: bool = ..., score: _Optional[_Union[_score_pb2.Score, _Mapping]] = ...) -> None: ...

class ParticipantChangedEvent(_message.Message):
    __slots__ = ("contest_id", "before", "after")
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    before: _participant_pb2.Participant
    after: _participant_pb2.Participant
    def __init__(self, contest_id: _Optional[str] = ..., before: _Optional[_Union[_participant_pb2.Participant, _Mapping]] = ..., after: _Optional[_Union[_participant_pb2.Participant, _Mapping]] = ...) -> None: ...

class ParticipantJoinedEvent(_message.Message):
    __slots__ = ("contest_id", "participant")
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    participant: _participant_pb2.Participant
    def __init__(self, contest_id: _Optional[str] = ..., participant: _Optional[_Union[_participant_pb2.Participant, _Mapping]] = ...) -> None: ...

class RetestProblemEvent(_message.Message):
    __slots__ = ("contest_id", "problem_id", "activity_id")
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVITY_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    problem_id: str
    activity_id: str
    def __init__(self, contest_id: _Optional[str] = ..., problem_id: _Optional[str] = ..., activity_id: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import access_key_pb2 as _access_key_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateAccessKeyInput(_message.Message):
    __slots__ = ("name", "scope", "expires_in")
    NAME_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    name: str
    scope: str
    expires_in: int
    def __init__(self, name: _Optional[str] = ..., scope: _Optional[str] = ..., expires_in: _Optional[int] = ...) -> None: ...

class CreateAccessKeyOutput(_message.Message):
    __slots__ = ("key_id", "secret")
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    key_id: str
    secret: str
    def __init__(self, key_id: _Optional[str] = ..., secret: _Optional[str] = ...) -> None: ...

class DeleteAccessKeyInput(_message.Message):
    __slots__ = ("key_id",)
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    key_id: str
    def __init__(self, key_id: _Optional[str] = ...) -> None: ...

class DeleteAccessKeyOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListAccessKeysInput(_message.Message):
    __slots__ = ("offset", "size")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListAccessKeysOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_access_key_pb2.AccessKey]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_access_key_pb2.AccessKey, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class AccountServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateAccount(self, request, **kwargs):
        path = "/account"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.CreateAccountOutput"),
            **kwargs,
        )

    def DescribeAccount(self, request, **kwargs):
        path = "/account"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.DescribeAccountOutput"),
            **kwargs,
        )

    def UpdateAccount(self, request, **kwargs):
        path = "/account"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.UpdateAccountOutput"),
            **kwargs,
        )

    def UploadPicture(self, request, **kwargs):
        path = "/account/picture"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.UploadPictureOutput"),
            **kwargs,
        )

    def DeleteAccount(self, request, **kwargs):
        path = "/account"

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.DeleteAccountOutput"),
            **kwargs,
        )

    def ResendVerification(self, request, **kwargs):
        path = "/account/verification/resend"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.ResendVerificationOutput"),
            **kwargs,
        )

    def CompleteVerification(self, request, **kwargs):
        path = "/account/verification/complete"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.CompleteVerificationOutput"),
            **kwargs,
        )

    def StartRecovery(self, request, **kwargs):
        path = "/account/recovery/start"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.StartRecoveryOutput"),
            **kwargs,
        )

    def CompleteRecovery(self, request, **kwargs):
        path = "/account/recovery/complete"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.CompleteRecoverOutput"),
            **kwargs,
        )

    def DescribeEmailSubscription(self, request, **kwargs):
        path = "/account/email-subscription"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.DescribeEmailSubscriptionOutput"),
            **kwargs,
        )

    def UpdateEmailSubscription(self, request, **kwargs):
        path = "/account/email-subscription"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.community.UpdateEmailSubscriptionOutput"),
            **kwargs,
        )




from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.helpdesk import auto_reply_pb2 as _auto_reply_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateAutoReplyInput(_message.Message):
    __slots__ = ("reply",)
    REPLY_FIELD_NUMBER: _ClassVar[int]
    reply: _auto_reply_pb2.AutoReply
    def __init__(self, reply: _Optional[_Union[_auto_reply_pb2.AutoReply, _Mapping]] = ...) -> None: ...

class CreateAutoReplyOutput(_message.Message):
    __slots__ = ("reply_id",)
    REPLY_ID_FIELD_NUMBER: _ClassVar[int]
    reply_id: str
    def __init__(self, reply_id: _Optional[str] = ...) -> None: ...

class UpdateAutoReplyInput(_message.Message):
    __slots__ = ("reply_id", "reply")
    REPLY_ID_FIELD_NUMBER: _ClassVar[int]
    REPLY_FIELD_NUMBER: _ClassVar[int]
    reply_id: str
    reply: _auto_reply_pb2.AutoReply
    def __init__(self, reply_id: _Optional[str] = ..., reply: _Optional[_Union[_auto_reply_pb2.AutoReply, _Mapping]] = ...) -> None: ...

class UpdateAutoReplyOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteAutoReplyInput(_message.Message):
    __slots__ = ("reply_id",)
    REPLY_ID_FIELD_NUMBER: _ClassVar[int]
    reply_id: str
    def __init__(self, reply_id: _Optional[str] = ...) -> None: ...

class DeleteAutoReplyOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListAutoRepliesInput(_message.Message):
    __slots__ = ("render", "offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("query", "id", "locale")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        query: str
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    RENDER_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    render: bool
    offset: int
    size: int
    filters: ListAutoRepliesInput.Filter
    def __init__(self, render: bool = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListAutoRepliesInput.Filter, _Mapping]] = ...) -> None: ...

class ListAutoRepliesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_auto_reply_pb2.AutoReply]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_auto_reply_pb2.AutoReply, _Mapping]]] = ...) -> None: ...

class DescribeAutoReplyInput(_message.Message):
    __slots__ = ("reply_id", "render")
    REPLY_ID_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    reply_id: str
    render: bool
    def __init__(self, reply_id: _Optional[str] = ..., render: bool = ...) -> None: ...

class DescribeAutoReplyOutput(_message.Message):
    __slots__ = ("reply",)
    REPLY_FIELD_NUMBER: _ClassVar[int]
    reply: _auto_reply_pb2.AutoReply
    def __init__(self, reply: _Optional[_Union[_auto_reply_pb2.AutoReply, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Contest(_message.Message):
    __slots__ = ("id", "url", "name", "logo_url", "starts_at", "starts_in", "ends_at", "ends_in", "duration", "status", "visibility", "join_unofficially", "participation_mode", "require_admission", "format", "key", "problem_count", "problem_count_hidden", "participant_count", "participant_count_hidden", "featured_until", "printer_id", "taxonomy", "appearance", "environment", "upsolve", "scoreboard")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATUS_UNKNOWN: _ClassVar[Contest.Status]
        SCHEDULED: _ClassVar[Contest.Status]
        OPEN: _ClassVar[Contest.Status]
        COMPLETE: _ClassVar[Contest.Status]
        SUSPENDED: _ClassVar[Contest.Status]
        FROZEN: _ClassVar[Contest.Status]
    STATUS_UNKNOWN: Contest.Status
    SCHEDULED: Contest.Status
    OPEN: Contest.Status
    COMPLETE: Contest.Status
    SUSPENDED: Contest.Status
    FROZEN: Contest.Status
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        VISIBILITY_UNKNOWN: _ClassVar[Contest.Visibility]
        PUBLIC: _ClassVar[Contest.Visibility]
        UNLISTED: _ClassVar[Contest.Visibility]
        PRIVATE: _ClassVar[Contest.Visibility]
    VISIBILITY_UNKNOWN: Contest.Visibility
    PUBLIC: Contest.Visibility
    UNLISTED: Contest.Visibility
    PRIVATE: Contest.Visibility
    class ParticipationMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PARTICIPATION_MODE_UNKNOWN: _ClassVar[Contest.ParticipationMode]
        ONLINE: _ClassVar[Contest.ParticipationMode]
        VIRTUAL: _ClassVar[Contest.ParticipationMode]
    PARTICIPATION_MODE_UNKNOWN: Contest.ParticipationMode
    ONLINE: Contest.ParticipationMode
    VIRTUAL: Contest.ParticipationMode
    class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        FORMAT_UNKNOWN: _ClassVar[Contest.Format]
        IOI: _ClassVar[Contest.Format]
        ICPC: _ClassVar[Contest.Format]
    FORMAT_UNKNOWN: Contest.Format
    IOI: Contest.Format
    ICPC: Contest.Format
    class Appearance(_message.Message):
        __slots__ = ("title", "description", "logo_url")
        TITLE_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        LOGO_URL_FIELD_NUMBER: _ClassVar[int]
        title: str
        description: str
        logo_url: str
        def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., logo_url: _Optional[str] = ...) -> None: ...
    class Taxonomy(_message.Message):
        __slots__ = ("year", "series", "scale", "difficulty", "country", "region", "city")
        class Scale(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_SCALE: _ClassVar[Contest.Taxonomy.Scale]
            LOCAL: _ClassVar[Contest.Taxonomy.Scale]
            REGIONAL: _ClassVar[Contest.Taxonomy.Scale]
            NATIONAL: _ClassVar[Contest.Taxonomy.Scale]
            INTERNATIONAL: _ClassVar[Contest.Taxonomy.Scale]
        UNKNOWN_SCALE: Contest.Taxonomy.Scale
        LOCAL: Contest.Taxonomy.Scale
        REGIONAL: Contest.Taxonomy.Scale
        NATIONAL: Contest.Taxonomy.Scale
        INTERNATIONAL: Contest.Taxonomy.Scale
        YEAR_FIELD_NUMBER: _ClassVar[int]
        SERIES_FIELD_NUMBER: _ClassVar[int]
        SCALE_FIELD_NUMBER: _ClassVar[int]
        DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
        COUNTRY_FIELD_NUMBER: _ClassVar[int]
        REGION_FIELD_NUMBER: _ClassVar[int]
        CITY_FIELD_NUMBER: _ClassVar[int]
        year: int
        series: str
        scale: Contest.Taxonomy.Scale
        difficulty: int
        country: str
        region: str
        city: str
        def __init__(self, year: _Optional[int] = ..., series: _Optional[str] = ..., scale: _Optional[_Union[Contest.Taxonomy.Scale, str]] = ..., difficulty: _Optional[int] = ..., country: _Optional[str] = ..., region: _Optional[str] = ..., city: _Optional[str] = ...) -> None: ...
    class Environment(_message.Message):
        __slots__ = ("allowed_runtimes",)
        ALLOWED_RUNTIMES_FIELD_NUMBER: _ClassVar[int]
        allowed_runtimes: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, allowed_runtimes: _Optional[_Iterable[str]] = ...) -> None: ...
    class Upsolve(_message.Message):
        __slots__ = ("free_upsolve", "virtual_upsolve")
        FREE_UPSOLVE_FIELD_NUMBER: _ClassVar[int]
        VIRTUAL_UPSOLVE_FIELD_NUMBER: _ClassVar[int]
        free_upsolve: bool
        virtual_upsolve: bool
        def __init__(self, free_upsolve: bool = ..., virtual_upsolve: bool = ...) -> None: ...
    class Scoreboard(_message.Message):
        __slots__ = ("visibility", "freezing_time", "unfreeze_delay", "attempt_penalty", "tie_breaker", "no_spoiler_ui", "share_key")
        class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_VISIBILITY: _ClassVar[Contest.Scoreboard.Visibility]
            INVISIBLE: _ClassVar[Contest.Scoreboard.Visibility]
            INTERNAL: _ClassVar[Contest.Scoreboard.Visibility]
            PUBLIC: _ClassVar[Contest.Scoreboard.Visibility]
        UNKNOWN_VISIBILITY: Contest.Scoreboard.Visibility
        INVISIBLE: Contest.Scoreboard.Visibility
        INTERNAL: Contest.Scoreboard.Visibility
        PUBLIC: Contest.Scoreboard.Visibility
        VISIBILITY_FIELD_NUMBER: _ClassVar[int]
        FREEZING_TIME_FIELD_NUMBER: _ClassVar[int]
        UNFREEZE_DELAY_FIELD_NUMBER: _ClassVar[int]
        ATTEMPT_PENALTY_FIELD_NUMBER: _ClassVar[int]
        TIE_BREAKER_FIELD_NUMBER: _ClassVar[int]
        NO_SPOILER_UI_FIELD_NUMBER: _ClassVar[int]
        SHARE_KEY_FIELD_NUMBER: _ClassVar[int]
        visibility: Contest.Scoreboard.Visibility
        freezing_time: int
        unfreeze_delay: int
        attempt_penalty: int
        tie_breaker: str
        no_spoiler_ui: bool
        share_key: str
        def __init__(self, visibility: _Optional[_Union[Contest.Scoreboard.Visibility, str]] = ..., freezing_time: _Optional[int] = ..., unfreeze_delay: _Optional[int] = ..., attempt_penalty: _Optional[int] = ..., tie_breaker: _Optional[str] = ..., no_spoiler_ui: bool = ..., share_key: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LOGO_URL_FIELD_NUMBER: _ClassVar[int]
    STARTS_AT_FIELD_NUMBER: _ClassVar[int]
    STARTS_IN_FIELD_NUMBER: _ClassVar[int]
    ENDS_AT_FIELD_NUMBER: _ClassVar[int]
    ENDS_IN_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    JOIN_UNOFFICIALLY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPATION_MODE_FIELD_NUMBER: _ClassVar[int]
    REQUIRE_ADMISSION_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_COUNT_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_COUNT_HIDDEN_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_COUNT_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_COUNT_HIDDEN_FIELD_NUMBER: _ClassVar[int]
    FEATURED_UNTIL_FIELD_NUMBER: _ClassVar[int]
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    TAXONOMY_FIELD_NUMBER: _ClassVar[int]
    APPEARANCE_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    name: str
    logo_url: str
    starts_at: _timestamp_pb2.Timestamp
    starts_in: int
    ends_at: _timestamp_pb2.Timestamp
    ends_in: int
    duration: int
    status: Contest.Status
    visibility: Contest.Visibility
    join_unofficially: bool
    participation_mode: Contest.ParticipationMode
    require_admission: bool
    format: Contest.Format
    key: str
    problem_count: int
    problem_count_hidden: bool
    participant_count: int
    participant_count_hidden: bool
    featured_until: _timestamp_pb2.Timestamp
    printer_id: str
    taxonomy: Contest.Taxonomy
    appearance: Contest.Appearance
    environment: Contest.Environment
    upsolve: Contest.Upsolve
    scoreboard: Contest.Scoreboard
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., name: _Optional[str] = ..., logo_url: _Optional[str] = ..., starts_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., starts_in: _Optional[int] = ..., ends_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ends_in: _Optional[int] = ..., duration: _Optional[int] = ..., status: _Optional[_Union[Contest.Status, str]] = ..., visibility: _Optional[_Union[Contest.Visibility, str]] = ..., join_unofficially: bool = ..., participation_mode: _Optional[_Union[Contest.ParticipationMode, str]] = ..., require_admission: bool = ..., format: _Optional[_Union[Contest.Format, str]] = ..., key: _Optional[str] = ..., problem_count: _Optional[int] = ..., problem_count_hidden: bool = ..., participant_count: _Optional[int] = ..., participant_count_hidden: bool = ..., featured_until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., printer_id: _Optional[str] = ..., taxonomy: _Optional[_Union[Contest.Taxonomy, _Mapping]] = ..., appearance: _Optional[_Union[Contest.Appearance, _Mapping]] = ..., environment: _Optional[_Union[Contest.Environment, _Mapping]] = ..., upsolve: _Optional[_Union[Contest.Upsolve, _Mapping]] = ..., scoreboard: _Optional[_Union[Contest.Scoreboard, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LinkedAccount(_message.Message):
    __slots__ = ("id", "type", "issuer", "subject")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_TYPE: _ClassVar[LinkedAccount.Type]
        GOOGLE: _ClassVar[LinkedAccount.Type]
    UNKNOWN_TYPE: LinkedAccount.Type
    GOOGLE: LinkedAccount.Type
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: LinkedAccount.Type
    issuer: str
    subject: str
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[LinkedAccount.Type, str]] = ..., issuer: _Optional[str] = ..., subject: _Optional[str] = ...) -> None: ...



from eolymp.judge import medal_pb2 as _medal_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Scoreboard(_message.Message):
    __slots__ = ("modes", "rounds", "columns")
    class Mode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        RESULT: _ClassVar[Scoreboard.Mode]
        FROZEN: _ClassVar[Scoreboard.Mode]
        UPSOLVE: _ClassVar[Scoreboard.Mode]
    RESULT: Scoreboard.Mode
    FROZEN: Scoreboard.Mode
    UPSOLVE: Scoreboard.Mode
    class Round(_message.Message):
        __slots__ = ("id", "title")
        ID_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        id: str
        title: str
        def __init__(self, id: _Optional[str] = ..., title: _Optional[str] = ...) -> None: ...
    class Column(_message.Message):
        __slots__ = ("id", "type", "title", "choices", "sortable", "filterable")
        class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_TYPE: _ClassVar[Scoreboard.Column.Type]
            ROUND_SCORE: _ClassVar[Scoreboard.Column.Type]
            PROBLEM_SCORE: _ClassVar[Scoreboard.Column.Type]
            STRING: _ClassVar[Scoreboard.Column.Type]
            NUMBER: _ClassVar[Scoreboard.Column.Type]
            CHOICE: _ClassVar[Scoreboard.Column.Type]
            DATE: _ClassVar[Scoreboard.Column.Type]
            EMAIL: _ClassVar[Scoreboard.Column.Type]
            CHECKBOX: _ClassVar[Scoreboard.Column.Type]
            COUNTRY: _ClassVar[Scoreboard.Column.Type]
            REGION: _ClassVar[Scoreboard.Column.Type]
            INSTITUTION: _ClassVar[Scoreboard.Column.Type]
        UNKNOWN_TYPE: Scoreboard.Column.Type
        ROUND_SCORE: Scoreboard.Column.Type
        PROBLEM_SCORE: Scoreboard.Column.Type
        STRING: Scoreboard.Column.Type
        NUMBER: Scoreboard.Column.Type
        CHOICE: Scoreboard.Column.Type
        DATE: Scoreboard.Column.Type
        EMAIL: Scoreboard.Column.Type
        CHECKBOX: Scoreboard.Column.Type
        COUNTRY: Scoreboard.Column.Type
        REGION: Scoreboard.Column.Type
        INSTITUTION: Scoreboard.Column.Type
        ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        CHOICES_FIELD_NUMBER: _ClassVar[int]
        SORTABLE_FIELD_NUMBER: _ClassVar[int]
        FILTERABLE_FIELD_NUMBER: _ClassVar[int]
        id: str
        type: Scoreboard.Column.Type
        title: str
        choices: _containers.RepeatedScalarFieldContainer[str]
        sortable: bool
        filterable: bool
        def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[Scoreboard.Column.Type, str]] = ..., title: _Optional[str] = ..., choices: _Optional[_Iterable[str]] = ..., sortable: bool = ..., filterable: bool = ...) -> None: ...
    class Row(_message.Message):
        __slots__ = ("id", "member_id", "index", "rank", "rank_length", "score", "penalty", "tie_breaker", "unofficial", "disqualified", "medal", "values")
        class Value(_message.Message):
            __slots__ = ("column_id", "round_score", "problem_score", "string", "number")
            COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
            ROUND_SCORE_FIELD_NUMBER: _ClassVar[int]
            PROBLEM_SCORE_FIELD_NUMBER: _ClassVar[int]
            STRING_FIELD_NUMBER: _ClassVar[int]
            NUMBER_FIELD_NUMBER: _ClassVar[int]
            column_id: str
            round_score: Scoreboard.Row.RoundScore
            problem_score: Scoreboard.Row.ProblemScore
            string: str
            number: str
            def __init__(self, column_id: _Optional[str] = ..., round_score: _Optional[_Union[Scoreboard.Row.RoundScore, _Mapping]] = ..., problem_score: _Optional[_Union[Scoreboard.Row.ProblemScore, _Mapping]] = ..., string: _Optional[str] = ..., number: _Optional[str] = ...) -> None: ...
        class RoundScore(_message.Message):
            __slots__ = ("score", "penalty", "tie_breaker", "unofficial", "disqualified", "medal")
            SCORE_FIELD_NUMBER: _ClassVar[int]
            PENALTY_FIELD_NUMBER: _ClassVar[int]
            TIE_BREAKER_FIELD_NUMBER: _ClassVar[int]
            UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
            DISQUALIFIED_FIELD_NUMBER: _ClassVar[int]
            MEDAL_FIELD_NUMBER: _ClassVar[int]
            score: float
            penalty: float
            tie_breaker: int
            unofficial: bool
            disqualified: bool
            medal: _medal_pb2.Medal
            def __init__(self, score: _Optional[float] = ..., penalty: _Optional[float] = ..., tie_breaker: _Optional[int] = ..., unofficial: bool = ..., disqualified: bool = ..., medal: _Optional[_Union[_medal_pb2.Medal, str]] = ...) -> None: ...
        class ProblemScore(_message.Message):
            __slots__ = ("score", "penalty", "attempts", "percentage", "time")
            SCORE_FIELD_NUMBER: _ClassVar[int]
            PENALTY_FIELD_NUMBER: _ClassVar[int]
            ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
            PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
            TIME_FIELD_NUMBER: _ClassVar[int]
            score: float
            penalty: float
            attempts: int
            percentage: float
            time: int
            def __init__(self, score: _Optional[float] = ..., penalty: _Optional[float] = ..., attempts: _Optional[int] = ..., percentage: _Optional[float] = ..., time: _Optional[int] = ...) -> None: ...
        ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        RANK_FIELD_NUMBER: _ClassVar[int]
        RANK_LENGTH_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        PENALTY_FIELD_NUMBER: _ClassVar[int]
        TIE_BREAKER_FIELD_NUMBER: _ClassVar[int]
        UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
        DISQUALIFIED_FIELD_NUMBER: _ClassVar[int]
        MEDAL_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        id: str
        member_id: str
        index: int
        rank: int
        rank_length: int
        score: float
        penalty: float
        tie_breaker: int
        unofficial: bool
        disqualified: bool
        medal: _medal_pb2.Medal
        values: _containers.RepeatedCompositeFieldContainer[Scoreboard.Row.Value]
        def __init__(self, id: _Optional[str] = ..., member_id: _Optional[str] = ..., index: _Optional[int] = ..., rank: _Optional[int] = ..., rank_length: _Optional[int] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., tie_breaker: _Optional[int] = ..., unofficial: bool = ..., disqualified: bool = ..., medal: _Optional[_Union[_medal_pb2.Medal, str]] = ..., values: _Optional[_Iterable[_Union[Scoreboard.Row.Value, _Mapping]]] = ...) -> None: ...
    MODES_FIELD_NUMBER: _ClassVar[int]
    ROUNDS_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    modes: _containers.RepeatedScalarFieldContainer[Scoreboard.Mode]
    rounds: _containers.RepeatedCompositeFieldContainer[Scoreboard.Round]
    columns: _containers.RepeatedCompositeFieldContainer[Scoreboard.Column]
    def __init__(self, modes: _Optional[_Iterable[_Union[Scoreboard.Mode, str]]] = ..., rounds: _Optional[_Iterable[_Union[Scoreboard.Round, _Mapping]]] = ..., columns: _Optional[_Iterable[_Union[Scoreboard.Column, _Mapping]]] = ...) -> None: ...



from eolymp.community import configuration_idp_pb2 as _configuration_idp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IdentityConfig(_message.Message):
    __slots__ = ("local", "basecamp", "oidc", "display_name_type", "display_name_attribute", "allow_sign_up", "require_email_verified")
    class DisplayNameType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_DISPLAY_NAME: _ClassVar[IdentityConfig.DisplayNameType]
        NICKNAME: _ClassVar[IdentityConfig.DisplayNameType]
        NAME: _ClassVar[IdentityConfig.DisplayNameType]
        ATTRIBUTE: _ClassVar[IdentityConfig.DisplayNameType]
    UNKNOWN_DISPLAY_NAME: IdentityConfig.DisplayNameType
    NICKNAME: IdentityConfig.DisplayNameType
    NAME: IdentityConfig.DisplayNameType
    ATTRIBUTE: IdentityConfig.DisplayNameType
    LOCAL_FIELD_NUMBER: _ClassVar[int]
    BASECAMP_FIELD_NUMBER: _ClassVar[int]
    OIDC_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_TYPE_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_SIGN_UP_FIELD_NUMBER: _ClassVar[int]
    REQUIRE_EMAIL_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    local: _configuration_idp_pb2.IdentityProvider.Local
    basecamp: _configuration_idp_pb2.IdentityProvider.Basecamp
    oidc: _configuration_idp_pb2.IdentityProvider.OIDC
    display_name_type: IdentityConfig.DisplayNameType
    display_name_attribute: str
    allow_sign_up: bool
    require_email_verified: bool
    def __init__(self, local: _Optional[_Union[_configuration_idp_pb2.IdentityProvider.Local, _Mapping]] = ..., basecamp: _Optional[_Union[_configuration_idp_pb2.IdentityProvider.Basecamp, _Mapping]] = ..., oidc: _Optional[_Union[_configuration_idp_pb2.IdentityProvider.OIDC, _Mapping]] = ..., display_name_type: _Optional[_Union[IdentityConfig.DisplayNameType, str]] = ..., display_name_attribute: _Optional[str] = ..., allow_sign_up: bool = ..., require_email_verified: bool = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ScoringMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NO_SCORE: _ClassVar[ScoringMode]
    EACH: _ClassVar[ScoringMode]
    ALL: _ClassVar[ScoringMode]
    WORST: _ClassVar[ScoringMode]
    BEST: _ClassVar[ScoringMode]
NO_SCORE: ScoringMode
EACH: ScoringMode
ALL: ScoringMode
WORST: ScoringMode
BEST: ScoringMode



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Action(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_ACTION: _ClassVar[Action]
    SPACE_LIST: _ClassVar[Action]
    SPACE_READ: _ClassVar[Action]
    SPACE_WRITE: _ClassVar[Action]
    SPACE_DELETE: _ClassVar[Action]
    BILLING_READ: _ClassVar[Action]
    BILLING_WRITE: _ClassVar[Action]
    POLICY_LIST: _ClassVar[Action]
    POLICY_READ: _ClassVar[Action]
    POLICY_WRITE: _ClassVar[Action]
    PROBLEM_LIST: _ClassVar[Action]
    PROBLEM_READ: _ClassVar[Action]
    PROBLEM_WRITE: _ClassVar[Action]
    PROBLEM_TESTING: _ClassVar[Action]
    CONTEST_LIST: _ClassVar[Action]
    CONTEST_READ: _ClassVar[Action]
    CONTEST_WRITE: _ClassVar[Action]
    CONTEST_ADMIT: _ClassVar[Action]
    TICKET_LIST: _ClassVar[Action]
    TICKET_READ: _ClassVar[Action]
    TICKET_WRITE: _ClassVar[Action]
    MEMBER_LIST: _ClassVar[Action]
    MEMBER_READ: _ClassVar[Action]
    MEMBER_WRITE: _ClassVar[Action]
    SCOREBOARD_LIST: _ClassVar[Action]
    SCOREBOARD_READ: _ClassVar[Action]
    SCOREBOARD_WRITE: _ClassVar[Action]
    CONTENT_LIST: _ClassVar[Action]
    CONTENT_READ: _ClassVar[Action]
    CONTENT_WRITE: _ClassVar[Action]
    COURSE_LIST: _ClassVar[Action]
    COURSE_READ: _ClassVar[Action]
    COURSE_WRITE: _ClassVar[Action]
    COURSE_ASSIGN: _ClassVar[Action]
    POST_LIST: _ClassVar[Action]
    POST_READ: _ClassVar[Action]
    POST_WRITE: _ClassVar[Action]
UNKNOWN_ACTION: Action
SPACE_LIST: Action
SPACE_READ: Action
SPACE_WRITE: Action
SPACE_DELETE: Action
BILLING_READ: Action
BILLING_WRITE: Action
POLICY_LIST: Action
POLICY_READ: Action
POLICY_WRITE: Action
PROBLEM_LIST: Action
PROBLEM_READ: Action
PROBLEM_WRITE: Action
PROBLEM_TESTING: Action
CONTEST_LIST: Action
CONTEST_READ: Action
CONTEST_WRITE: Action
CONTEST_ADMIT: Action
TICKET_LIST: Action
TICKET_READ: Action
TICKET_WRITE: Action
MEMBER_LIST: Action
MEMBER_READ: Action
MEMBER_WRITE: Action
SCOREBOARD_LIST: Action
SCOREBOARD_READ: Action
SCOREBOARD_WRITE: Action
CONTENT_LIST: Action
CONTENT_READ: Action
CONTENT_WRITE: Action
COURSE_LIST: Action
COURSE_READ: Action
COURSE_WRITE: Action
COURSE_ASSIGN: Action
POST_LIST: Action
POST_READ: Action
POST_WRITE: Action



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Configuration(_message.Message):
    __slots__ = ("members_can_create_posts", "members_can_comment_on_posts", "members_can_comment_on_problems", "post_moderation", "comment_moderation")
    class Moderation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_MODERATION: _ClassVar[Configuration.Moderation]
        NO_MODERATION: _ClassVar[Configuration.Moderation]
        PRE_MODERATION: _ClassVar[Configuration.Moderation]
        POST_MODERATION: _ClassVar[Configuration.Moderation]
    UNKNOWN_MODERATION: Configuration.Moderation
    NO_MODERATION: Configuration.Moderation
    PRE_MODERATION: Configuration.Moderation
    POST_MODERATION: Configuration.Moderation
    MEMBERS_CAN_CREATE_POSTS_FIELD_NUMBER: _ClassVar[int]
    MEMBERS_CAN_COMMENT_ON_POSTS_FIELD_NUMBER: _ClassVar[int]
    MEMBERS_CAN_COMMENT_ON_PROBLEMS_FIELD_NUMBER: _ClassVar[int]
    POST_MODERATION_FIELD_NUMBER: _ClassVar[int]
    COMMENT_MODERATION_FIELD_NUMBER: _ClassVar[int]
    members_can_create_posts: bool
    members_can_comment_on_posts: bool
    members_can_comment_on_problems: bool
    post_moderation: Configuration.Moderation
    comment_moderation: Configuration.Moderation
    def __init__(self, members_can_create_posts: bool = ..., members_can_comment_on_posts: bool = ..., members_can_comment_on_problems: bool = ..., post_moderation: _Optional[_Union[Configuration.Moderation, str]] = ..., comment_moderation: _Optional[_Union[Configuration.Moderation, str]] = ...) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Material(_message.Message):
    __slots__ = ("id", "url", "draft", "name", "image_url", "module_id", "index", "depth", "grading", "document", "task", "percentage", "grade", "progress")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EXTRA: _ClassVar[Material.Extra]
        CONTENT: _ClassVar[Material.Extra]
        CONTENT_VALUE: _ClassVar[Material.Extra]
        CONTENT_RENDER: _ClassVar[Material.Extra]
        PERCENTAGE: _ClassVar[Material.Extra]
        GRADE: _ClassVar[Material.Extra]
        PROGRESS: _ClassVar[Material.Extra]
    UNKNOWN_EXTRA: Material.Extra
    CONTENT: Material.Extra
    CONTENT_VALUE: Material.Extra
    CONTENT_RENDER: Material.Extra
    PERCENTAGE: Material.Extra
    GRADE: Material.Extra
    PROGRESS: Material.Extra
    class Document(_message.Message):
        __slots__ = ("content",)
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        content: _content_pb2.Content
        def __init__(self, content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...
    class Task(_message.Message):
        __slots__ = ("problem_id",)
        PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        problem_id: str
        def __init__(self, problem_id: _Optional[str] = ...) -> None: ...
    class Grading(_message.Message):
        __slots__ = ("max_score", "weight")
        MAX_SCORE_FIELD_NUMBER: _ClassVar[int]
        WEIGHT_FIELD_NUMBER: _ClassVar[int]
        max_score: int
        weight: float
        def __init__(self, max_score: _Optional[int] = ..., weight: _Optional[float] = ...) -> None: ...
    class Progress(_message.Message):
        __slots__ = ("percentage", "grade", "grade_automatic", "grade_override", "excused")
        PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
        GRADE_FIELD_NUMBER: _ClassVar[int]
        GRADE_AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
        GRADE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
        EXCUSED_FIELD_NUMBER: _ClassVar[int]
        percentage: float
        grade: int
        grade_automatic: int
        grade_override: int
        excused: bool
        def __init__(self, percentage: _Optional[float] = ..., grade: _Optional[int] = ..., grade_automatic: _Optional[int] = ..., grade_override: _Optional[int] = ..., excused: bool = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    DRAFT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    DEPTH_FIELD_NUMBER: _ClassVar[int]
    GRADING_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    TASK_FIELD_NUMBER: _ClassVar[int]
    PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    GRADE_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    draft: bool
    name: str
    image_url: str
    module_id: str
    index: int
    depth: int
    grading: Material.Grading
    document: Material.Document
    task: Material.Task
    percentage: float
    grade: int
    progress: Material.Progress
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., draft: bool = ..., name: _Optional[str] = ..., image_url: _Optional[str] = ..., module_id: _Optional[str] = ..., index: _Optional[int] = ..., depth: _Optional[int] = ..., grading: _Optional[_Union[Material.Grading, _Mapping]] = ..., document: _Optional[_Union[Material.Document, _Mapping]] = ..., task: _Optional[_Union[Material.Task, _Mapping]] = ..., percentage: _Optional[float] = ..., grade: _Optional[int] = ..., progress: _Optional[_Union[Material.Progress, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/code_template_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/code_template_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import code_template_pb2 as eolymp_dot_atlas_dot_code__template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/atlas/code_template_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/atlas/code_template.proto\"C\n\x17\x43reateCodeTemplateInput\x12(\n\x08template\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Template\"/\n\x18\x43reateCodeTemplateOutput\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\"\xb2\x01\n\x17UpdateCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\x12(\n\x08template\x18\x03 \x01(\x0b\x32\x16.eolymp.atlas.Template\"X\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07RUNTIME\x10\x01\x12\n\n\x06SOURCE\x10\x02\x12\n\n\x06HEADER\x10\x03\x12\n\n\x06\x46OOTER\x10\x04\x12\n\n\x06SECRET\x10\x05\x12\t\n\x05\x46ILES\x10\x06\"\x1a\n\x18UpdateCodeTemplateOutput\".\n\x17\x44\x65leteCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteCodeTemplateOutput\"G\n\x16ListCodeTemplatesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0f\n\x07version\x18\x64 \x01(\r\"O\n\x17ListCodeTemplatesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.atlas.Template\"A\n\x19\x44\x65scribeCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"F\n\x1a\x44\x65scribeCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\"*\n\x17LookupCodeTemplateInput\x12\x0f\n\x07runtime\x18\x02 \x01(\t\"D\n\x18LookupCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template2\x96\x08\n\x13\x43odeTemplateService\x12\xa1\x01\n\x12\x43reateCodeTemplate\x12%.eolymp.atlas.CreateCodeTemplateInput\x1a&.eolymp.atlas.CreateCodeTemplateOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0c\"\n/templates\x12\xaf\x01\n\x12UpdateCodeTemplate\x12%.eolymp.atlas.UpdateCodeTemplateInput\x1a&.eolymp.atlas.UpdateCodeTemplateOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1a\"\x18/templates/{template_id}\x12\xaf\x01\n\x12\x44\x65leteCodeTemplate\x12%.eolymp.atlas.DeleteCodeTemplateInput\x1a&.eolymp.atlas.DeleteCodeTemplateOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1a*\x18/templates/{template_id}\x12\x9d\x01\n\x11ListCodeTemplates\x12$.eolymp.atlas.ListCodeTemplatesInput\x1a%.eolymp.atlas.ListCodeTemplatesOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x0c\x12\n/templates\x12\xb4\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.atlas.DescribeCodeTemplateInput\x1a(.eolymp.atlas.DescribeCodeTemplateOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x1a\x12\x18/templates/{template_id}\x12\x9f\x01\n\x12LookupCodeTemplate\x12%.eolymp.atlas.LookupCodeTemplateInput\x1a&.eolymp.atlas.LookupCodeTemplateOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x0b\x12\t/templateB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.code_template_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_CODETEMPLATESERVICE'].methods_by_name['CreateCodeTemplate']._loaded_options = None
  _globals['_CODETEMPLATESERVICE'].methods_by_name['CreateCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\014\"\n/templates'
  _globals['_CODETEMPLATESERVICE'].methods_by_name['UpdateCodeTemplate']._loaded_options = None
  _globals['_CODETEMPLATESERVICE'].methods_by_name['UpdateCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\032\"\030/templates/{template_id}'
  _globals['_CODETEMPLATESERVICE'].methods_by_name['DeleteCodeTemplate']._loaded_options = None
  _globals['_CODETEMPLATESERVICE'].methods_by_name['DeleteCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\032*\030/templates/{template_id}'
  _globals['_CODETEMPLATESERVICE'].methods_by_name['ListCodeTemplates']._loaded_options = None
  _globals['_CODETEMPLATESERVICE'].methods_by_name['ListCodeTemplates']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\014\022\n/templates'
  _globals['_CODETEMPLATESERVICE'].methods_by_name['DescribeCodeTemplate']._loaded_options = None
  _globals['_CODETEMPLATESERVICE'].methods_by_name['DescribeCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\032\022\030/templates/{template_id}'
  _globals['_CODETEMPLATESERVICE'].methods_by_name['LookupCodeTemplate']._loaded_options = None
  _globals['_CODETEMPLATESERVICE'].methods_by_name['LookupCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\013\022\t/template'
  _globals['_CREATECODETEMPLATEINPUT']._serialized_start=191
  _globals['_CREATECODETEMPLATEINPUT']._serialized_end=258
  _globals['_CREATECODETEMPLATEOUTPUT']._serialized_start=260
  _globals['_CREATECODETEMPLATEOUTPUT']._serialized_end=307
  _globals['_UPDATECODETEMPLATEINPUT']._serialized_start=310
  _globals['_UPDATECODETEMPLATEINPUT']._serialized_end=488
  _globals['_UPDATECODETEMPLATEINPUT_PATCH']._serialized_start=400
  _globals['_UPDATECODETEMPLATEINPUT_PATCH']._serialized_end=488
  _globals['_UPDATECODETEMPLATEOUTPUT']._serialized_start=490
  _globals['_UPDATECODETEMPLATEOUTPUT']._serialized_end=516
  _globals['_DELETECODETEMPLATEINPUT']._serialized_start=518
  _globals['_DELETECODETEMPLATEINPUT']._serialized_end=564
  _globals['_DELETECODETEMPLATEOUTPUT']._serialized_start=566
  _globals['_DELETECODETEMPLATEOUTPUT']._serialized_end=592
  _globals['_LISTCODETEMPLATESINPUT']._serialized_start=594
  _globals['_LISTCODETEMPLATESINPUT']._serialized_end=665
  _globals['_LISTCODETEMPLATESOUTPUT']._serialized_start=667
  _globals['_LISTCODETEMPLATESOUTPUT']._serialized_end=746
  _globals['_DESCRIBECODETEMPLATEINPUT']._serialized_start=748
  _globals['_DESCRIBECODETEMPLATEINPUT']._serialized_end=813
  _globals['_DESCRIBECODETEMPLATEOUTPUT']._serialized_start=815
  _globals['_DESCRIBECODETEMPLATEOUTPUT']._serialized_end=885
  _globals['_LOOKUPCODETEMPLATEINPUT']._serialized_start=887
  _globals['_LOOKUPCODETEMPLATEINPUT']._serialized_end=929
  _globals['_LOOKUPCODETEMPLATEOUTPUT']._serialized_start=931
  _globals['_LOOKUPCODETEMPLATEOUTPUT']._serialized_end=999
  _globals['_CODETEMPLATESERVICE']._serialized_start=1002
  _globals['_CODETEMPLATESERVICE']._serialized_end=2048
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Preferences(_message.Message):
    __slots__ = ("subscriptions",)
    class Digest(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_DIGEST: _ClassVar[Preferences.Digest]
        IMMEDIATE: _ClassVar[Preferences.Digest]
        HOURLY: _ClassVar[Preferences.Digest]
        DAILY: _ClassVar[Preferences.Digest]
    UNKNOWN_DIGEST: Preferences.Digest
    IMMEDIATE: Preferences.Digest
    HOURLY: Preferences.Digest
    DAILY: Preferences.Digest
    class Subscription(_message.Message):
        __slots__ = ("topic", "digest")
        TOPIC_FIELD_NUMBER: _ClassVar[int]
        DIGEST_FIELD_NUMBER: _ClassVar[int]
        topic: str
        digest: Preferences.Digest
        def __init__(self, topic: _Optional[str] = ..., digest: _Optional[_Union[Preferences.Digest, str]] = ...) -> None: ...
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    subscriptions: _containers.RepeatedCompositeFieldContainer[Preferences.Subscription]
    def __init__(self, subscriptions: _Optional[_Iterable[_Union[Preferences.Subscription, _Mapping]]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import material_pb2 as _material_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateMaterialInput(_message.Message):
    __slots__ = ("material", "module_id")
    MATERIAL_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    material: _material_pb2.Material
    module_id: str
    def __init__(self, material: _Optional[_Union[_material_pb2.Material, _Mapping]] = ..., module_id: _Optional[str] = ...) -> None: ...

class CreateMaterialOutput(_message.Message):
    __slots__ = ("material_id",)
    MATERIAL_ID_FIELD_NUMBER: _ClassVar[int]
    material_id: str
    def __init__(self, material_id: _Optional[str] = ...) -> None: ...

class UpdateMaterialInput(_message.Message):
    __slots__ = ("patch", "material_id", "material")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateMaterialInput.Patch]
        DRAFT: _ClassVar[UpdateMaterialInput.Patch]
        NAME: _ClassVar[UpdateMaterialInput.Patch]
        IMAGE_URL: _ClassVar[UpdateMaterialInput.Patch]
        INDEX: _ClassVar[UpdateMaterialInput.Patch]
        DEPTH: _ClassVar[UpdateMaterialInput.Patch]
        CONTENT: _ClassVar[UpdateMaterialInput.Patch]
        GRADING: _ClassVar[UpdateMaterialInput.Patch]
    ALL: UpdateMaterialInput.Patch
    DRAFT: UpdateMaterialInput.Patch
    NAME: UpdateMaterialInput.Patch
    IMAGE_URL: UpdateMaterialInput.Patch
    INDEX: UpdateMaterialInput.Patch
    DEPTH: UpdateMaterialInput.Patch
    CONTENT: UpdateMaterialInput.Patch
    GRADING: UpdateMaterialInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    MATERIAL_ID_FIELD_NUMBER: _ClassVar[int]
    MATERIAL_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateMaterialInput.Patch]
    material_id: str
    material: _material_pb2.Material
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateMaterialInput.Patch, str]]] = ..., material_id: _Optional[str] = ..., material: _Optional[_Union[_material_pb2.Material, _Mapping]] = ...) -> None: ...

class UpdateMaterialOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MoveMaterialInput(_message.Message):
    __slots__ = ("material_id", "new_module_id", "new_index", "new_depth")
    MATERIAL_ID_FIELD_NUMBER: _ClassVar[int]
    NEW_MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    NEW_INDEX_FIELD_NUMBER: _ClassVar[int]
    NEW_DEPTH_FIELD_NUMBER: _ClassVar[int]
    material_id: str
    new_module_id: str
    new_index: int
    new_depth: int
    def __init__(self, material_id: _Optional[str] = ..., new_module_id: _Optional[str] = ..., new_index: _Optional[int] = ..., new_depth: _Optional[int] = ...) -> None: ...

class MoveMaterialOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteMaterialInput(_message.Message):
    __slots__ = ("material_id",)
    MATERIAL_ID_FIELD_NUMBER: _ClassVar[int]
    material_id: str
    def __init__(self, material_id: _Optional[str] = ...) -> None: ...

class DeleteMaterialOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeMaterialInput(_message.Message):
    __slots__ = ("material_id", "member_id", "extra")
    MATERIAL_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    material_id: str
    member_id: str
    extra: _containers.RepeatedScalarFieldContainer[_material_pb2.Material.Extra]
    def __init__(self, material_id: _Optional[str] = ..., member_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_material_pb2.Material.Extra, str]]] = ...) -> None: ...

class DescribeMaterialOutput(_message.Message):
    __slots__ = ("material",)
    MATERIAL_FIELD_NUMBER: _ClassVar[int]
    material: _material_pb2.Material
    def __init__(self, material: _Optional[_Union[_material_pb2.Material, _Mapping]] = ...) -> None: ...

class ListMaterialsInput(_message.Message):
    __slots__ = ("module_id", "member_id", "search", "offset", "size", "filters", "sort", "order", "extra")
    class Sort(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INDEX: _ClassVar[ListMaterialsInput.Sort]
    INDEX: ListMaterialsInput.Sort
    class Filter(_message.Message):
        __slots__ = ("graded", "weight")
        GRADED_FIELD_NUMBER: _ClassVar[int]
        WEIGHT_FIELD_NUMBER: _ClassVar[int]
        graded: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        weight: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        def __init__(self, graded: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., weight: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ...) -> None: ...
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    module_id: str
    member_id: str
    search: str
    offset: int
    size: int
    filters: ListMaterialsInput.Filter
    sort: ListMaterialsInput.Sort
    order: _direction_pb2.Direction
    extra: _containers.RepeatedScalarFieldContainer[_material_pb2.Material.Extra]
    def __init__(self, module_id: _Optional[str] = ..., member_id: _Optional[str] = ..., search: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListMaterialsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListMaterialsInput.Sort, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., extra: _Optional[_Iterable[_Union[_material_pb2.Material.Extra, str]]] = ...) -> None: ...

class ListMaterialsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_material_pb2.Material]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_material_pb2.Material, _Mapping]]] = ...) -> None: ...

class ReportProgressInput(_message.Message):
    __slots__ = ("material_id", "progress")
    MATERIAL_ID_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    material_id: str
    progress: float
    def __init__(self, material_id: _Optional[str] = ..., progress: _Optional[float] = ...) -> None: ...

class ReportProgressOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GradeMaterialInput(_message.Message):
    __slots__ = ("material_id", "member_id", "grade", "excused")
    MATERIAL_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    GRADE_FIELD_NUMBER: _ClassVar[int]
    EXCUSED_FIELD_NUMBER: _ClassVar[int]
    material_id: str
    member_id: str
    grade: int
    excused: bool
    def __init__(self, material_id: _Optional[str] = ..., member_id: _Optional[str] = ..., grade: _Optional[int] = ..., excused: bool = ...) -> None: ...

class GradeMaterialOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/evaluation_report.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/executor/evaluation_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import stats_pb2 as eolymp_dot_executor_dot_stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/executor/evaluation_report.proto\x12\x0f\x65olymp.executor\x1a\x1b\x65olymp/executor/stats.proto\"\xc1\n\n\x10\x45valuationReport\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t\x12\x41\n\x08metadata\x18\x05 \x03(\x0b\x32/.eolymp.executor.EvaluationReport.MetadataEntry\x12\r\n\x05\x61gent\x18\x04 \x01(\t\x12\x11\n\tsignature\x18\x32 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x34\n\x04type\x18\n \x01(\x0e\x32&.eolymp.executor.EvaluationReport.Type\x12\x38\n\x06status\x18\x0b \x01(\x0e\x32(.eolymp.executor.EvaluationReport.Status\x12\x15\n\rerror_message\x18\x14 \x01(\t\x12\x33\n\x04runs\x18( \x03(\x0b\x32%.eolymp.executor.EvaluationReport.Run\x1a\xc4\x05\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12<\n\x06status\x18\x02 \x01(\x0e\x32,.eolymp.executor.EvaluationReport.Run.Status\x12\r\n\x05score\x18P \x01(\x02\x12\x0c\n\x04\x63ost\x18Q \x01(\x02\x12\x12\n\ntime_usage\x18\x33 \x01(\r\x12\x12\n\ntime_limit\x18= \x01(\r\x12\x11\n\tcpu_usage\x18\x34 \x01(\r\x12\x11\n\tcpu_limit\x18> \x01(\r\x12\x14\n\x0cmemory_usage\x18\x35 \x01(\x04\x12\x14\n\x0cmemory_limit\x18? \x01(\x04\x12\x18\n\x10time_coefficient\x18\x0e \x01(\x02\x12\x11\n\tinput_url\x18\n \x01(\t\x12\x12\n\noutput_url\x18\x0b \x01(\t\x12\x12\n\nanswer_url\x18\x0c \x01(\t\x12+\n\x0b\x64\x65\x62ug_stats\x18Z \x01(\x0b\x32\x16.eolymp.executor.Stats\x12-\n\rchecker_stats\x18# \x01(\x0b\x32\x16.eolymp.executor.Stats\x12\x30\n\x10interactor_stats\x18- \x01(\x0b\x32\x16.eolymp.executor.Stats\"\xf1\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x11\n\rRUNTIME_ERROR\x10\x06\x12\x0c\n\x08\x45XECUTED\x10\x07\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x08\x12\x10\n\x0cWRONG_ANSWER\x10\t\x12\x18\n\x14VERIFICATION_FAILURE\x10\n\x12\x0b\n\x07SKIPPED\x10\x0b\x12\x17\n\x13INTERACTION_FAILURE\x10\x0c\x12\x0b\n\x07\x42LOCKED\x10\r\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x10\n\x0cPROVISIONING\x10\x02\x12\x10\n\x0cINITIALIZING\x10\x03\x12\r\n\tEXECUTING\x10\x04\x12\x0c\n\x08\x43OMPLETE\x10\x05\x12\t\n\x05\x45RROR\x10\x06\x12\n\n\x06\x46\x41ILED\x10\x07\"K\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0f\n\x0bTYPE_UPDATE\x10\x01\x12\x0e\n\nTYPE_ERROR\x10\x02\x12\x10\n\x0cTYPE_FAILURE\x10\x03\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.evaluation_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_EVALUATIONREPORT_METADATAENTRY']._loaded_options = None
  _globals['_EVALUATIONREPORT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EVALUATIONREPORT']._serialized_start=90
  _globals['_EVALUATIONREPORT']._serialized_end=1435
  _globals['_EVALUATIONREPORT_RUN']._serialized_start=469
  _globals['_EVALUATIONREPORT_RUN']._serialized_end=1177
  _globals['_EVALUATIONREPORT_RUN_STATUS']._serialized_start=936
  _globals['_EVALUATIONREPORT_RUN_STATUS']._serialized_end=1177
  _globals['_EVALUATIONREPORT_METADATAENTRY']._serialized_start=1179
  _globals['_EVALUATIONREPORT_METADATAENTRY']._serialized_end=1226
  _globals['_EVALUATIONREPORT_STATUS']._serialized_start=1229
  _globals['_EVALUATIONREPORT_STATUS']._serialized_end=1358
  _globals['_EVALUATIONREPORT_TYPE']._serialized_start=1360
  _globals['_EVALUATIONREPORT_TYPE']._serialized_end=1435
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import node_pb2 as _node_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Content(_message.Message):
    __slots__ = ("html", "latex", "markdown", "ecm", "render")
    HTML_FIELD_NUMBER: _ClassVar[int]
    LATEX_FIELD_NUMBER: _ClassVar[int]
    MARKDOWN_FIELD_NUMBER: _ClassVar[int]
    ECM_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    html: str
    latex: str
    markdown: str
    ecm: _node_pb2.Node
    render: _node_pb2.Node
    def __init__(self, html: _Optional[str] = ..., latex: _Optional[str] = ..., markdown: _Optional[str] = ..., ecm: _Optional[_Union[_node_pb2.Node, _Mapping]] = ..., render: _Optional[_Union[_node_pb2.Node, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/universe.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/universe/universe.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.universe import space_service_pb2 as eolymp_dot_universe_dot_space__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/universe/universe.proto\x12\x0f\x65olymp.universe\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a#eolymp/universe/space_service.proto2\x8c\t\n\x08Universe\x12\x83\x01\n\x0bLookupSpace\x12!.eolymp.universe.LookupSpaceInput\x1a\".eolymp.universe.LookupSpaceOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x18\x12\x16/spaces/__lookup/{key}\x12\x90\x01\n\x0b\x43reateSpace\x12!.eolymp.universe.CreateSpaceInput\x1a\".eolymp.universe.CreateSpaceOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\x82\xd3\xe4\x93\x02\t\"\x07/spaces\x12\x9b\x01\n\x0bUpdateSpace\x12!.eolymp.universe.UpdateSpaceInput\x1a\".eolymp.universe.UpdateSpaceOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\x82\xd3\xe4\x93\x02\x14\x1a\x12/spaces/{space_id}\x12\x9b\x01\n\x0b\x44\x65leteSpace\x12!.eolymp.universe.DeleteSpaceInput\x1a\".eolymp.universe.DeleteSpaceOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\x82\xd3\xe4\x93\x02\x14*\x12/spaces/{space_id}\x12\x85\x01\n\rDescribeSpace\x12#.eolymp.universe.DescribeSpaceInput\x1a$.eolymp.universe.DescribeSpaceOutput\")\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x14\x12\x12/spaces/{space_id}\x12\x8b\x01\n\rDescribeQuota\x12#.eolymp.universe.DescribeQuotaInput\x1a$.eolymp.universe.DescribeQuotaOutput\"/\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1a\x12\x18/spaces/{space_id}/quota\x12\x85\x01\n\x0bUpdateQuota\x12!.eolymp.universe.UpdateQuotaInput\x1a\".eolymp.universe.UpdateQuotaOutput\"/\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1a\x1a\x18/spaces/{space_id}/quota\x12\x8c\x01\n\nListSpaces\x12 .eolymp.universe.ListSpacesInput\x1a!.eolymp.universe.ListSpacesOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\x82\xd3\xe4\x93\x02\t\x12\x07/spacesB3Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.universe_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_UNIVERSE'].methods_by_name['LookupSpace']._loaded_options = None
  _globals['_UNIVERSE'].methods_by_name['LookupSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\030\022\026/spaces/__lookup/{key}'
  _globals['_UNIVERSE'].methods_by_name['CreateSpace']._loaded_options = None
  _globals['_UNIVERSE'].methods_by_name['CreateSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\030\212\343\n\024universe:space:write\202\323\344\223\002\t\"\007/spaces'
  _globals['_UNIVERSE'].methods_by_name['UpdateSpace']._loaded_options = None
  _globals['_UNIVERSE'].methods_by_name['UpdateSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\030\212\343\n\024universe:space:write\202\323\344\223\002\024\032\022/spaces/{space_id}'
  _globals['_UNIVERSE'].methods_by_name['DeleteSpace']._loaded_options = None
  _globals['_UNIVERSE'].methods_by_name['DeleteSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024universe:space:write\202\323\344\223\002\024*\022/spaces/{space_id}'
  _globals['_UNIVERSE'].methods_by_name['DescribeSpace']._loaded_options = None
  _globals['_UNIVERSE'].methods_by_name['DescribeSpace']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\024\022\022/spaces/{space_id}'
  _globals['_UNIVERSE'].methods_by_name['DescribeQuota']._loaded_options = None
  _globals['_UNIVERSE'].methods_by_name['DescribeQuota']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\032\022\030/spaces/{space_id}/quota'
  _globals['_UNIVERSE'].methods_by_name['UpdateQuota']._loaded_options = None
  _globals['_UNIVERSE'].methods_by_name['UpdateQuota']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\032\032\030/spaces/{space_id}/quota'
  _globals['_UNIVERSE'].methods_by_name['ListSpaces']._loaded_options = None
  _globals['_UNIVERSE'].methods_by_name['ListSpaces']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023universe:space:read\202\323\344\223\002\t\022\007/spaces'
  _globals['_UNIVERSE']._serialized_start=188
  _globals['_UNIVERSE']._serialized_end=1352
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/session_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/community/session_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import session_pb2 as eolymp_dot_community_dot_session__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/community/session_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/community/session.proto\x1a!eolymp/wellknown/expression.proto\"*\n\x14\x44\x65scribeSessionInput\x12\x12\n\nsession_id\x18\x01 \x01(\t\"C\n\x15\x44\x65scribeSessionOutput\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x19.eolymp.community.Session\"\xd6\x02\n\x11ListSessionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.community.ListSessionsInput.Filter\x1a\xe5\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\nip_address\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12<\n\rfirst_seen_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12;\n\x0clast_seen_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"M\n\x12ListSessionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.community.Session\"+\n\x15TerminateSessionInput\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\x18\n\x16TerminateSessionOutput\"/\n\x19TerminateAllSessionsInput\x12\x12\n\nsession_id\x18\x01 \x01(\t\"H\n\x1aTerminateAllSessionsOutput\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x19.eolymp.community.Session2\xdb\x05\n\x0eSessionService\x12\xae\x01\n\x0f\x44\x65scribeSession\x12&.eolymp.community.DescribeSessionInput\x1a\'.eolymp.community.DescribeSessionOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x18\x12\x16/sessions/{session_id}\x12\x98\x01\n\x0cListSessions\x12#.eolymp.community.ListSessionsInput\x1a$.eolymp.community.ListSessionsOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x0b\x12\t/sessions\x12\xbb\x01\n\x10TerminateSession\x12\'.eolymp.community.TerminateSessionInput\x1a(.eolymp.community.TerminateSessionOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\"\" /sessions/{session_id}/terminate\x12\xbe\x01\n\x14TerminateAllSessions\x12+.eolymp.community.TerminateAllSessionsInput\x1a,.eolymp.community.TerminateAllSessionsOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x19\"\x17/sessions:terminate-allB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.session_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_SESSIONSERVICE'].methods_by_name['DescribeSession']._loaded_options = None
  _globals['_SESSIONSERVICE'].methods_by_name['DescribeSession']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\030\022\026/sessions/{session_id}'
  _globals['_SESSIONSERVICE'].methods_by_name['ListSessions']._loaded_options = None
  _globals['_SESSIONSERVICE'].methods_by_name['ListSessions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\013\022\t/sessions'
  _globals['_SESSIONSERVICE'].methods_by_name['TerminateSession']._loaded_options = None
  _globals['_SESSIONSERVICE'].methods_by_name['TerminateSession']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\"\" /sessions/{session_id}/terminate'
  _globals['_SESSIONSERVICE'].methods_by_name['TerminateAllSessions']._loaded_options = None
  _globals['_SESSIONSERVICE'].methods_by_name['TerminateAllSessions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\031\"\027/sessions:terminate-all'
  _globals['_DESCRIBESESSIONINPUT']._serialized_start=226
  _globals['_DESCRIBESESSIONINPUT']._serialized_end=268
  _globals['_DESCRIBESESSIONOUTPUT']._serialized_start=270
  _globals['_DESCRIBESESSIONOUTPUT']._serialized_end=337
  _globals['_LISTSESSIONSINPUT']._serialized_start=340
  _globals['_LISTSESSIONSINPUT']._serialized_end=682
  _globals['_LISTSESSIONSINPUT_FILTER']._serialized_start=453
  _globals['_LISTSESSIONSINPUT_FILTER']._serialized_end=682
  _globals['_LISTSESSIONSOUTPUT']._serialized_start=684
  _globals['_LISTSESSIONSOUTPUT']._serialized_end=761
  _globals['_TERMINATESESSIONINPUT']._serialized_start=763
  _globals['_TERMINATESESSIONINPUT']._serialized_end=806
  _globals['_TERMINATESESSIONOUTPUT']._serialized_start=808
  _globals['_TERMINATESESSIONOUTPUT']._serialized_end=832
  _globals['_TERMINATEALLSESSIONSINPUT']._serialized_start=834
  _globals['_TERMINATEALLSESSIONSINPUT']._serialized_end=881
  _globals['_TERMINATEALLSESSIONSOUTPUT']._serialized_start=883
  _globals['_TERMINATEALLSESSIONSOUTPUT']._serialized_end=955
  _globals['_SESSIONSERVICE']._serialized_start=958
  _globals['_SESSIONSERVICE']._serialized_end=1689
# @@protoc_insertion_point(module_scope)
